@@ -1,6 +1,7 @@
 """Extract reference documentation from the NumPy source tree.
 
 """
+
 import inspect
 import textwrap
 import re
@@ -705,6 +706,7 @@ class ClassDoc(NumpyDocString):
             for name, func in inspect.getmembers(self._cls)
             if (
                 not name.startswith("_")
+                and not self._should_skip_member(name, self._cls)
                 and (
                     func is None
                     or isinstance(func, (property, cached_property))
@@ -714,6 +716,19 @@ class ClassDoc(NumpyDocString):
             )
         ]
 
+    @staticmethod
+    def _should_skip_member(name, klass):
+        if (
+            # Namedtuples should skip everything in their ._fields as the
+            # docstrings for each of the members is: "Alias for field number X"
+            issubclass(klass, tuple)
+            and hasattr(klass, "_asdict")
+            and hasattr(klass, "_fields")
+            and name in klass._fields
+        ):
+            return True
+        return False
+
     def _is_show_member(self, name):
         if self.show_inherited_members:
             return True  # show all class members
